| Title: | Edge Selection |
|---|---|
| Description: | Implementation of the Edge Selection Algorithm for undirected graph selection. The least angle regression-based algorithm selects edges of an undirected graph based on the projection of the current residuals on the two dimensional edge-planes. The algorithm selects symmetric adjacency matrix, which many other regression-based undirected graph selection procedures cannot do. |
| Authors: | Sanjay Chaudhuri [aut, cre], Victor Meng Hui [aut] |
| Maintainer: | Sanjay Chaudhuri <[email protected]> |
| License: | GPL-2 |
| Version: | 1.1 |
| Built: | 2026-06-03 09:42:57 UTC |
| Source: | https://github.com/cran/ES |
Implementation of the Edge Selection Algorithm
| Package: | ESpackage |
| Type: | Package |
| Version: | 1.0 |
| Date: | 2013-06-13 |
| License: | CRAN |
Meng Hwee Victor Ong, Sanjay Chaudhuri
Edge Selection for Undirected Graphs
Computes K-Fold cross validation based on mean squared prediction error.
cv.ES(x,object,K=10,M)cv.ES(x,object,K=10,M)
x |
Data Matrix. The columns represent the different variables, while the rows represent identically and independently distributed samples. |
object |
Lars object, generated from ES function. |
K |
Number of Folds in cross validation. |
M |
A vector of values that determine the points where cross validation are done. If not specified, the value of M will be determined using the object |
cv.ES picks a model which minimizes the mean squared prediction errors using the input vector M. cv.ES also pick a model with a mean squared prediction error less than or equals to the minimum mean square prediction plus its standard error.
Edge Selection for Undirected Graphs
ES, ESpredict
data(marks) attach(marks) object <- ES(marks) cv.ES(marks,object) detach(marks)data(marks) attach(marks) object <- ES(marks) cv.ES(marks,object) detach(marks)
ES generates the entire sequence of coefficient estimates using Edge Selection Algorithm.
ES(u, maxstop)ES(u, maxstop)
u |
Data Matrix. The columns represent the different variables, while the rows represent identically and independently distributed samples. |
maxstop |
Number of edges selected before the algorithm stops. If it is not specified, the algorithm will run until all the variables are added. |
An object is returned, which includes the entire sequence of ES coefficient estimates, OLS estimates and the correlations of the first two edges that is added to the algorithm.
Edge Selection for Undirected Graphs
ESpredict, cv.ES
data(marks) attach(marks) object <- ES(marks) detach(marks)data(marks) attach(marks) object <- ES(marks) detach(marks)
ESpredict extract coefficient estimates from a fitted ES object.
ESpredict(object, c)ESpredict(object, c)
object |
Fitted ES object |
c |
A vector of values that indexes the path. Values should fall between 0 and the maximum of object$c1. |
Vector or Matrix of Coefficients estimates.
Edge Selection for Undirected Graphs
Es, cv.ES
data(marks) attach(marks) object <- ES(marks) ESpredict(object,c=object$c1) detach(marks)data(marks) attach(marks) object <- ES(marks) ESpredict(object,c=object$c1) detach(marks)
Mathematic Marks from ggm package
data(marks)data(marks)
A data frame with 88 observations on the following 5 variables.
mechanicsa numeric vector
vectorsa numeric vector
algebraa numeric vector
analysisa numeric vector
statisticsa numeric vector
Mechanics and Vectors were closed book examinations. Algebra, Analysis and Statistics were open book examinations.
Mardia, K.V., Kent, J.T. and Bibby, (1979). Multivariate analysis. London: Academic Press.
Whittaker, J. (1990). Graphical models in applied multivariate statistics. Chichester: Wiley.
data(marks)data(marks)